Module sumcheck

Module sumcheck 

The sumcheck interactive proof protocol.

Proves claims of the form sum_{x in {0,1}^n} g(x) = v where g is a multilinear polynomial. The protocol runs in n rounds, reducing verification to a single evaluation of g at a random point.

Re-exports

pub use protocol::RoundPoly;
pub use protocol::SumcheckClaim;
pub use protocol::SumcheckProof;
pub use prover::sumcheck_prove;
pub use verifier::sumcheck_verify;

Modules

protocol
Sumcheck protocol types.
prover
Sumcheck prover.
verifier
Sumcheck verifier.